@@ -31,19 +31,20 @@ example_metadata = {
 exacmple_record = {"field1": "test", "field2": 999}
 
 
-def test(token, test_rows=10, batch_size=None):
+def test(client, test_rows=None, batch_size=None):
+    test_rows = test_rows or 1
     example_data = pd.DataFrame([exacmple_record] * test_rows)
     timestamp = datetime.datetime.now().strftime("%Y%m%d%H%M%S")
     tablename = "test_%s_%d" % (timestamp, random.randint(100000, 999999))
-    cl = OepClient(token=token, tablename=tablename)
-    cl.create(metadata=example_metadata)
+    self.settings["tablename"] = tablename
+    client.create(metadata=example_metadata)
     try:
-        cl.upload_data(dataframe=example_data, batch_size=batch_size)
-        cl.update_metadata(metadata=example_metadata)
-        data = cl.download_data()
-        metadata = cl.download_metadata()
+        client.upload_data(dataframe=example_data, batch_size=batch_size)
+        client.update_metadata(metadata=example_metadata)
+        data = client.download_data()
+        metadata = client.download_metadata()
         print(len(data))
         print(data[0])
         print(metadata)
     finally:
-        cl.delete()
+        client.delete()
